==> speech-analytic-testing_6.1.0_database.tar.gz: database/mssql/procedures/SaveEvaluationFormat.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveEvaluationFormat] (
	@Instance Varchar(50) = NULL, 						
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type Varchar(50) = NULL,
	@EnvironmentType VARCHAR(50) = NULL,
	@CreatedDate Datetime = NULL,						
	@CreatedByUserId Varchar(50) = NULL,		
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,			
	@MinQualificationAcceptable numeric(5,2),	
	@MinAutomaticQualification NUMERIC(5, 2),
	@ManagementFormURL varchar(1000) = NULL,
	@Enabled bit = NULL, 
	@templateId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- Danny Jhonston:
	-- Inicio:
	-- Validar si el formato tiene al menos un plan asignado.
	-- Validar si el formato tiene un plan de evaluacion que tiene evaluaciones pendientes.

	-- DECLARE @ID VARCHAR(50)
	-- SET @ID = '183fedb7-9dbf-4b1c-8efd-b1164f33c8ba'

	-- Tabla temporal para almacenar resultado de consulta.
	DECLARE @EvaluationsData TABLE (
		[ID]						VARCHAR(50),
		[totalEvaluations]			INT,
		[completedEvaluations]		INT
	)
	INSERT INTO @EvaluationsData
	SELECT
		EP.[ID]									'id',
		COUNT(AEP.[IdInteraction])				'totalEvaluations',
		SUM(CAST(AEP.[Completed] AS INT))		'completedEvaluations'
	FROM
		[dbo].[EvaluationPlan] EP
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP ON EP.[ID] = AEP.[IdEvaluationPlan]
	WHERE
		EP.[Instance] = @Instance
		AND EP.[IdEvaluationFormat] = @ID
	GROUP BY EP.[ID]

	-- Contiene las evaluaciones de un formato.
	DECLARE @TotalEvaluations INT
	SET @TotalEvaluations = (SELECT COUNT([ID]) FROM @EvaluationsData WHERE (CAST([completedEvaluations] AS NUMERIC(18, 2)) / CAST([totalEvaluations] AS NUMERIC(18, 2))) * 100 > 0)
	-- SET @TotalEvaluations = (SELECT COUNT([ID]) FROM @EvaluationsData WHERE [totalEvaluations] > [completedEvaluations])

	--PRINT @TotalEvaluations
	IF(@TotalEvaluations < 1)
	BEGIN
		BEGIN
			-- Tiene evaluaciones asociadas que en al menos se esta evaluando un plan de evaluacion.
			SELECT CAST(-1 AS INT) 'idEvaluationFormat'
			PRINT @@ROWCOUNT
		END
	END
	ELSE
	-- Danny Jhonston:
	-- Fin:
	BEGIN
		-- No tiene evaluaciones asociadas.
		-- Debe continuar con el guardado.

		UPDATE [EvaluationFormat] SET
			[Description] = @Description,
			[Type] = @Type,
			[EnvironmentType] = @EnvironmentType,
			[MinQualificationAcceptable] = @MinQualificationAcceptable,
			[MinAutomaticQualification] = @MinAutomaticQualification,
			[ManagementFormURL] = @ManagementFormURL,
			[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
			[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
			[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
			[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
			[Enabled] = CASE WHEN @Enabled IS NULL THEN 1 ELSE @Enabled END,
			[TimeStamp] = GETUTCDATE(),
			[templateId] = @templateId
		WHERE [Instance] = @Instance
		AND [ID] = @ID

		

		IF @@ROWCOUNT = 0
			INSERT INTO [EvaluationFormat] (
				[Instance],[ID], [Description], [Type], 
				[EnvironmentType], [MinQualificationAcceptable], [MinAutomaticQualification], [ManagementFormURL],
				[CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId],
				[Enabled], [TimeStamp], [templateId]
				)
			VALUES (
				@Instance, @ID, @Description, @Type, 
				@EnvironmentType, @MinQualificationAcceptable, @MinAutomaticQualification, @ManagementFormURL,
				@CreatedDate, @CreatedByUserId, @LastModifiedDate, @LastModifiedByUserId,
				@Enabled, GETUTCDATE(), @templateId
			)

		SELECT CAST(Scope_Identity() AS INT) as 'idEvaluationFormat';
	END

	

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_7.8.2_database.tar.gz: database/mssql/procedures/SaveEvaluationFormat.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveEvaluationFormat] (
	@Instance Varchar(50) = NULL, 						
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type Varchar(50) = NULL,
	@EnvironmentType VARCHAR(50) = NULL,
	@CreatedDate Datetime = NULL,						
	@CreatedByUserId Varchar(50) = NULL,		
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,			
	@MinQualificationAcceptable numeric(5,2),	
	@MinAutomaticQualification NUMERIC(5, 2),
	@ManagementFormURL varchar(1000) = NULL,
	@Enabled bit = NULL, 
	@templateId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- Danny Jhonston:
	-- Inicio:
	-- Validar si el formato tiene al menos un plan asignado.
	-- Validar si el formato tiene un plan de evaluacion que tiene evaluaciones pendientes.

	-- DECLARE @ID VARCHAR(50)
	-- SET @ID = '183fedb7-9dbf-4b1c-8efd-b1164f33c8ba'

	-- Tabla temporal para almacenar resultado de consulta.
	/*DECLARE @EvaluationsData TABLE (
		[ID]						VARCHAR(50),
		[totalEvaluations]			INT,
		[completedEvaluations]		INT
	)
	INSERT INTO @EvaluationsData
	SELECT
		EP.[ID]									'id',
		COUNT(AEP.[IdInteraction])				'totalEvaluations',
		SUM(CAST(AEP.[Completed] AS INT))		'completedEvaluations'
	FROM
		[dbo].[EvaluationPlan] EP
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP ON EP.[ID] = AEP.[IdEvaluationPlan]
	WHERE
		EP.[Instance] = @Instance
		AND EP.[IdEvaluationFormat] = @ID
	GROUP BY EP.[ID]

	-- Contiene las evaluaciones de un formato.
	DECLARE @TotalEvaluations INT
	SET @TotalEvaluations = (SELECT COUNT([ID]) FROM @EvaluationsData WHERE (CAST([completedEvaluations] AS NUMERIC(18, 2)) / CAST([totalEvaluations] AS NUMERIC(18, 2))) * 100 > 0)
	-- SET @TotalEvaluations = (SELECT COUNT([ID]) FROM @EvaluationsData WHERE [totalEvaluations] > [completedEvaluations])

	--PRINT @TotalEvaluations
	IF(@TotalEvaluations < 1)
	BEGIN
		BEGIN
			-- Tiene evaluaciones asociadas que en al menos se esta evaluando un plan de evaluacion.
			SELECT CAST(-1 AS INT) 'idEvaluationFormat'
			PRINT @@ROWCOUNT
		END
	END
	ELSE
	-- Danny Jhonston:
	-- Fin:
	*/
	BEGIN
		-- No tiene evaluaciones asociadas.
		-- Debe continuar con el guardado.

		UPDATE [EvaluationFormat] SET
			[Description] = @Description,
			[Type] = @Type,
			[EnvironmentType] = @EnvironmentType,
			[MinQualificationAcceptable] = @MinQualificationAcceptable,
			[MinAutomaticQualification] = @MinAutomaticQualification,
			[ManagementFormURL] = @ManagementFormURL,
			[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
			[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
			[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
			[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
			[Enabled] = CASE WHEN @Enabled IS NULL THEN 1 ELSE @Enabled END,
			[TimeStamp] = GETUTCDATE(),
			[templateId] = @templateId
		WHERE [Instance] = @Instance
		AND [ID] = @ID

		

		IF @@ROWCOUNT = 0
			INSERT INTO [EvaluationFormat] (
				[Instance],[ID], [Description], [Type], 
				[EnvironmentType], [MinQualificationAcceptable], [MinAutomaticQualification], [ManagementFormURL],
				[CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId],
				[Enabled], [TimeStamp], [templateId]
				)
			VALUES (
				@Instance, @ID, @Description, @Type, 
				@EnvironmentType, @MinQualificationAcceptable, @MinAutomaticQualification, @ManagementFormURL,
				@CreatedDate, @CreatedByUserId, @LastModifiedDate, @LastModifiedByUserId,
				@Enabled, GETUTCDATE(), @templateId
			)

		SELECT CAST(Scope_Identity() AS INT) as 'idEvaluationFormat';
	END

	

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
